==> promethist_common_lib-0.1.0-py3-none-any.whl: promethist/common/init.py <==
# -*- coding: utf-8 -*-
import datetime
import json
import logging
import logging.config
import time
import sys
import os

import connexion
from flask import g, request
from flask_cors import CORS

from promethist.common.utils import DateTimeEncoder, init_swagger_host
from promethist.common.config import CONFIG


def create_app(module_name):
    """
    Set up Flask app.
    :param testing: app for testing purposes
    :return: Flask app
    """

    cur_dir = os.path.dirname(sys.argv[0])
    spec_dir = os.path.join(cur_dir, f'{module_name}/api')
    init_swagger_host(module_name, spec_dir)
    app = connexion.FlaskApp(__name__, specification_dir=spec_dir)

    app.app.config['LOG_LEVEL'] = CONFIG["logger"]["level"]
    configure_logger(app.app)

    app.add_api(CONFIG["api"]["name"])

    if CONFIG["testing"]:
        return app

    # TODO: Deal with allowed origins.
    CORS(app.app, origins=CONFIG["cors"]["origins"],
         expose_headers=CONFIG["cors"]["expose_headers"],
         supports_credentials=CONFIG["cors"]["supports_credentials"])

    return app


def configure_logger(app):
    """
    Set up logging.
    :param app: Flask app
    """

    @app.before_request
    def start_timer():
        g.start = time.time()

    @app.after_request
    def log_request(response):

        if request.path == '/favicon.ico' or request.path.startswith('/static'):
            return response

        if request.query_string:
            path_query = f"{request.path}?{request.query_string.decode('utf-8')}"
        else:
            path_query = request.path

        duration = round(time.time() - g.start, 3)

        log_params = {
            'method': request.method,
            'path': path_query,
            'status': response.status_code,
            'duration': duration,
            'ip': request.headers.get('X-Forwarded-For', request.remote_addr),
            'host': request.host
        }

        request_id = request.headers.get('X-Request-ID')
        if request_id:
            log_params['request_id'] = request_id

        if request.is_json and request.get_data():
            log_params['request_body'] = request.get_json()

        if response.is_json and response.get_data():
            log_params['response_body'] = response.get_json()

        app.logger.info(json.dumps(log_params, cls=DateTimeEncoder))
        return response

    logging.config.dictConfig(CONFIG["logger"])

    app.logger.setLevel(logging.getLevelName(CONFIG["logger"]["level"]))
    app.logger.debug("Logger started %s", datetime.datetime.utcnow())

==> promethist_common_lib-0.1.1-py3-none-any.whl: promethist/common/init.py <==
# -*- coding: utf-8 -*-
import datetime
import json
import logging
import logging.config
import time
import sys
import os

import connexion
from flask import g, request
from flask_cors import CORS

from promethist.common.utils import DateTimeEncoder, init_swagger_host
from promethist.common.config import CONFIG


def create_app(module_name):
    """
    Set up Flask app.
    :param testing: app for testing purposes
    :return: Flask app
    """

    cur_dir = os.path.abspath(os.curdir)
    spec_dir = os.path.join(cur_dir, f'{module_name}/api')
    init_swagger_host(module_name, spec_dir)
    app = connexion.FlaskApp(__name__, specification_dir=spec_dir)

    app.app.config['LOG_LEVEL'] = CONFIG["logger"]["level"]
    configure_logger(app.app)

    app.add_api(CONFIG["api"]["name"])

    if CONFIG["testing"]:
        return app

    # TODO: Deal with allowed origins.
    CORS(app.app, origins=CONFIG["cors"]["origins"],
         expose_headers=CONFIG["cors"]["expose_headers"],
         supports_credentials=CONFIG["cors"]["supports_credentials"])

    return app


def configure_logger(app):
    """
    Set up logging.
    :param app: Flask app
    """

    @app.before_request
    def start_timer():
        g.start = time.time()

    @app.after_request
    def log_request(response):

        if request.path == '/favicon.ico' or request.path.startswith('/static'):
            return response

        if request.query_string:
            path_query = f"{request.path}?{request.query_string.decode('utf-8')}"
        else:
            path_query = request.path

        duration = round(time.time() - g.start, 3)

        log_params = {
            'method': request.method,
            'path': path_query,
            'status': response.status_code,
            'duration': duration,
            'ip': request.headers.get('X-Forwarded-For', request.remote_addr),
            'host': request.host
        }

        request_id = request.headers.get('X-Request-ID')
        if request_id:
            log_params['request_id'] = request_id

        if request.is_json and request.get_data():
            log_params['request_body'] = request.get_json()

        if response.is_json and response.get_data():
            log_params['response_body'] = response.get_json()

        app.logger.info(json.dumps(log_params, cls=DateTimeEncoder))
        return response

    logging.config.dictConfig(CONFIG["logger"])

    app.logger.setLevel(logging.getLevelName(CONFIG["logger"]["level"]))
    app.logger.debug("Logger started %s", datetime.datetime.utcnow())
